/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __MM_GDBUS_CBM_H__
#define __MM_GDBUS_CBM_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.ModemManager1.Cbm */

#define MM_GDBUS_TYPE_CBM (mm_gdbus_cbm_get_type ())
#define MM_GDBUS_CBM(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MM_GDBUS_TYPE_CBM, MmGdbusCbm))
#define MM_GDBUS_IS_CBM(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MM_GDBUS_TYPE_CBM))
#define MM_GDBUS_CBM_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), MM_GDBUS_TYPE_CBM, MmGdbusCbmIface))

struct _MmGdbusCbm;
typedef struct _MmGdbusCbm MmGdbusCbm;
typedef struct _MmGdbusCbmIface MmGdbusCbmIface;

struct _MmGdbusCbmIface
{
  GTypeInterface parent_iface;

  guint  (*get_channel) (MmGdbusCbm *object);

  guint  (*get_message_code) (MmGdbusCbm *object);

  guint  (*get_state) (MmGdbusCbm *object);

  const gchar * (*get_text) (MmGdbusCbm *object);

  guint  (*get_update) (MmGdbusCbm *object);

};

GType mm_gdbus_cbm_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *mm_gdbus_cbm_interface_info (void);
guint mm_gdbus_cbm_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus property accessors: */
guint mm_gdbus_cbm_get_state (MmGdbusCbm *object);
void mm_gdbus_cbm_set_state (MmGdbusCbm *object, guint value);

const gchar *mm_gdbus_cbm_get_text (MmGdbusCbm *object);
gchar *mm_gdbus_cbm_dup_text (MmGdbusCbm *object);
void mm_gdbus_cbm_set_text (MmGdbusCbm *object, const gchar *value);

guint mm_gdbus_cbm_get_channel (MmGdbusCbm *object);
void mm_gdbus_cbm_set_channel (MmGdbusCbm *object, guint value);

guint mm_gdbus_cbm_get_message_code (MmGdbusCbm *object);
void mm_gdbus_cbm_set_message_code (MmGdbusCbm *object, guint value);

guint mm_gdbus_cbm_get_update (MmGdbusCbm *object);
void mm_gdbus_cbm_set_update (MmGdbusCbm *object, guint value);


/* ---- */

#define MM_GDBUS_TYPE_CBM_PROXY (mm_gdbus_cbm_proxy_get_type ())
#define MM_GDBUS_CBM_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MM_GDBUS_TYPE_CBM_PROXY, MmGdbusCbmProxy))
#define MM_GDBUS_CBM_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), MM_GDBUS_TYPE_CBM_PROXY, MmGdbusCbmProxyClass))
#define MM_GDBUS_CBM_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MM_GDBUS_TYPE_CBM_PROXY, MmGdbusCbmProxyClass))
#define MM_GDBUS_IS_CBM_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MM_GDBUS_TYPE_CBM_PROXY))
#define MM_GDBUS_IS_CBM_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), MM_GDBUS_TYPE_CBM_PROXY))

typedef struct _MmGdbusCbmProxy MmGdbusCbmProxy;
typedef struct _MmGdbusCbmProxyClass MmGdbusCbmProxyClass;
typedef struct _MmGdbusCbmProxyPrivate MmGdbusCbmProxyPrivate;

struct _MmGdbusCbmProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  MmGdbusCbmProxyPrivate *priv;
};

struct _MmGdbusCbmProxyClass
{
  GDBusProxyClass parent_class;
};

GType mm_gdbus_cbm_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MmGdbusCbmProxy, g_object_unref)
#endif

void mm_gdbus_cbm_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MmGdbusCbm *mm_gdbus_cbm_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
MmGdbusCbm *mm_gdbus_cbm_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void mm_gdbus_cbm_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
MmGdbusCbm *mm_gdbus_cbm_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
MmGdbusCbm *mm_gdbus_cbm_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define MM_GDBUS_TYPE_CBM_SKELETON (mm_gdbus_cbm_skeleton_get_type ())
#define MM_GDBUS_CBM_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), MM_GDBUS_TYPE_CBM_SKELETON, MmGdbusCbmSkeleton))
#define MM_GDBUS_CBM_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), MM_GDBUS_TYPE_CBM_SKELETON, MmGdbusCbmSkeletonClass))
#define MM_GDBUS_CBM_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MM_GDBUS_TYPE_CBM_SKELETON, MmGdbusCbmSkeletonClass))
#define MM_GDBUS_IS_CBM_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), MM_GDBUS_TYPE_CBM_SKELETON))
#define MM_GDBUS_IS_CBM_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), MM_GDBUS_TYPE_CBM_SKELETON))

typedef struct _MmGdbusCbmSkeleton MmGdbusCbmSkeleton;
typedef struct _MmGdbusCbmSkeletonClass MmGdbusCbmSkeletonClass;
typedef struct _MmGdbusCbmSkeletonPrivate MmGdbusCbmSkeletonPrivate;

struct _MmGdbusCbmSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  MmGdbusCbmSkeletonPrivate *priv;
};

struct _MmGdbusCbmSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType mm_gdbus_cbm_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MmGdbusCbmSkeleton, g_object_unref)
#endif

MmGdbusCbm *mm_gdbus_cbm_skeleton_new (void);


G_END_DECLS

#endif /* __MM_GDBUS_CBM_H__ */
